MobkitCalendarAppointmentModel class

The event model used for MobkitCalendarWidget.

Constructors

MobkitCalendarAppointmentModel({String? nativeEventId, required String? title, required DateTime appointmentStartDate, required DateTime appointmentEndDate, Color? color, required bool isAllDay, required String detail, required RecurrenceModel? recurrenceModel, Object? eventData})

Properties

appointmentEndDate DateTime
getter/setter pair
appointmentStartDate DateTime
getter/setter pair
color Color?
getter/setter pair
detail String
getter/setter pair
eventData Object?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
index int?
getter/setter pair
isAllDay bool
getter/setter pair
nativeEventId String?
getter/setter pair
recurrenceModel RecurrenceModel?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited